#
# spec file for package perl-App-perlbrew
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name App-perlbrew
Name:           perl-App-perlbrew
Version:        0.980.0
Release:        2.4
%define cpan_version 0.98
License:        MIT
Summary:        Manage perl installations in your $HOME
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/G/GU/GUGOD/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(CPAN::Perl::Releases) >= 5.20230720
BuildRequires:  perl(Capture::Tiny) >= 0.48
BuildRequires:  perl(Devel::PatchPerl) >= 2.08
BuildRequires:  perl(ExtUtils::MakeMaker) >= 7.22
BuildRequires:  perl(File::Temp) >= 0.2304
BuildRequires:  perl(File::Which) >= 1.21
BuildRequires:  perl(IO::All) >= 0.51
BuildRequires:  perl(JSON::PP)
BuildRequires:  perl(Module::Build::Tiny) >= 0.039
BuildRequires:  perl(Path::Class) >= 0.33
BuildRequires:  perl(Pod::Usage) >= 1.69
BuildRequires:  perl(Test::Exception) >= 0.32
BuildRequires:  perl(Test::More) >= 1.001002
BuildRequires:  perl(Test::NoWarnings) >= 1.04
BuildRequires:  perl(Test::Output) >= 1.03
BuildRequires:  perl(Test::Simple) >= 1.001002
BuildRequires:  perl(Test::Spec) >= 0.49
BuildRequires:  perl(Test::TempDir::Tiny) >= 0.016
BuildRequires:  perl(local::lib) >= 2.000014
Requires:       perl(CPAN::Perl::Releases) >= 5.20230720
Requires:       perl(Capture::Tiny) >= 0.48
Requires:       perl(Devel::PatchPerl) >= 2.08
Requires:       perl(ExtUtils::MakeMaker) >= 7.22
Requires:       perl(File::Temp) >= 0.2304
Requires:       perl(JSON::PP)
Requires:       perl(Pod::Usage) >= 1.69
Requires:       perl(local::lib) >= 2.000014
Provides:       perl(App::Perlbrew::HTTP)
Provides:       perl(App::Perlbrew::Path)
Provides:       perl(App::Perlbrew::Path::Installation)
Provides:       perl(App::Perlbrew::Path::Installations)
Provides:       perl(App::Perlbrew::Path::Root)
Provides:       perl(App::Perlbrew::Util)
Provides:       perl(App::perlbrew) = 0.980.0
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  wget curl groff
# MANUAL END

%description
perlbrew is a program to automate the building and installation of perl in
an easy way. It provides multiple isolated perl environments, and a
mechanism for you to switch between them.

Everything are installed unter '~/perl5/perlbrew'. You then need to include
a bashrc/cshrc provided by perlbrew to tweak the PATH for you. You then can
benefit from not having to run 'sudo' commands to install cpan modules
because those are installed inside your 'HOME' too.

For the documentation of perlbrew usage see perlbrew command on at
https://metacpan.org/, or by running 'perlbrew help', or by visiting at
https://perlbrew.pl/. The following documentation features the API of
'App::perlbrew' module, and may not be remotely close to what your want to
read.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

# MANUAL BEGIN
chmod a+x t/fake-bin/curl
# MANUAL END

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING.md README
%license LICENSE

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Sat Aug 12 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.98
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.98
  - Released at 2023-08-11T22:54:38+0900
  - Remove the support of cperl from `available` and `install` command. Github PR: #777. cperl can still be installed by specifying the tarball, just not by their short names.
  - new command: make-shim
  - new command: make-pp.
* Sat May 13 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.97
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.97
  - Released at 2023-05-12T22:33:42+0900
  - Thanks to our contributors: Elvin Aslanov, Graham Knop, Shoichi Kaji, Tomasz Konojacki, brian greenfield
  - The documentation of `clone-module` and `list-modules` are improved.
  - No longer depends on Pod::Parser. Github PR #760
  - Bugfix for csh users: Github PR #770
* Mon Aug  1 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.96
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.96
  - Released at 2022-07-31T15:42:39+0900
  - Thanks to our contributors: Rolf Stöckli
  - `install-cpm` is now properly documented. Thanks to Tekki.
  - Let `install` hint for `init` when PERLBREW_ROOT does not exist. .RT #57669.
  - Reveal the actual error code of curl/wget etc. Github issue #748.
* Mon May 16 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.95
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.95
  - Released at 2022-05-15T22:59:11+0800
  - Thanks to our contributors: Leon Timmermans
  - Now we use metacpan api for fetching perl versions and for downloading. Github PR #743
  - `--verbose` flag now also enable verbosity of underlying curl/wget commands. Github PR #740.
  - Avoid perl test errors when NO_COLOR is set. Github PR #738
* Sun Dec  5 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.94
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.94
  - Released at 2021-12-05T08:39:16+0900
  - Let `self-upgrade` print version numbers when doing upgrades. Github issue #678.
  0.93
  - Released at 2021-11-22T23:09:25+0900
  - Let `clone-modules` takes just one arguments and mean 'cloning modules from that perl'.
  - Let `list-modules` and `clone-modules` map certain output to their representative module name. Github issue #722
  - `exec` command now takes aliases explicitly specified in `--with` args and run commands with those aliases -- even if that would run the same thing twice. Github issue #725
* Fri Apr 16 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.92
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.92
  - Released at 2021-04-15T23:53:55+0900
  - Thanks to our contributors: chee
  - Fix a message mentioning fish config. GitHub PR #712
  - Fetch cperl releases from https://github.com/perl11/cperl/releases instead
  - Let `clone-modules` command accept `--notest` and skip running module tests
* Mon Feb  1 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.91
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.91
  - Released at 2021-01-31T17:10:27+0900
  - Fix META info included in 0.90. No other feature changes.
  0.90
  - Released at 2021-01-29T09:43:17+0900
  - Thanks to our contributors: Mose Schmiedel, gucchisk
  - The output of 'available' command is split into sections of different type of distributions. Github issue #646.
  - Let the output of `perlbrew -h` be the short usage. Github issue #647
  - Unbreak env script for fish users. GitHub PR #698 and #708
  - Prefer https URLs of www.cpan.org
* Mon Oct 19 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.89
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.89
  - Released at 2020-10-19T09:26:19+0900
  - Thanks to our contributors: Håkon Hægland, Nicolas R, Peter Tripp
  - Make the bashrc compatible with 'bash -u'. Github PR #694
  - Prevent build directory from being overwritten. Github PR #683
* Thu Jan 30 2020 <timueller+perl@suse.de>
- updated to 0.88
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.88
  - Released at 2020-01-29T21:40:07+0900
  - Thanks to our contributors: Dave Rolsky, Gil Magno, Zhu Sheng Li
  - `install` command now shows errors message from http_downlod. Github PR #681.
  - Fix: The .tar.bz2 suffix are removed from the output ouf `available` PR #685
* Mon Oct 28 2019 <timueller+perl@suse.de>
- updated to 0.87
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.87
  - Released at 2019-10-25T22:55:40+0900
  - Thanks to our contributors: Branislav Zahradník, Christopher Chavez, Jon Jacobson, Konstantin S. Uvarin, Pali, Shoichi Kaji, Tomasz Konojacki, jkjacobson, rage311
  - Use the new official repo url for fetching perl blead. Github issue #677
  - Add `--min` and `--max` options to `exec` command. Github PR #656
  - Fix "ERROR: Cannot find the tarball for perl-$version". Github PR #669
  - Fix calling patchperl on readonly files. Github PR #674
  - Fix installation from local tarbal files. See https://rt.cpan.org/Ticket/Display.html?id=129871
  - Internal refactoring. Github PR #667, #662
  - Various corrections of documentation. Github PR #676, #660
* Sat Jan 19 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.86
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.86
  - Released at 2019-01-19T09:39:55+0900
  - Thanks to our contributors: Olaf Alders, Paul Cochrane
  - Fix an error from 'install' command.  https://rt.cpan.org/Public/Bug/Display.html?id=128083
  - Tweak the separater characters of 'exec' command: See https://github.com/gugod/App-perlbrew/issues/648
* Sun Dec 16 2018 Stephan Kulow <coolo@suse.com>
- updated to 0.85
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.85
  - Released at 2018-12-15T23:24:15+0900
  - Thanks to our contributors: Branislav Zahradník, Guido Flohr, Joelle Maslak, Luca Ferrari, rage311
  - Fix the behaviour of 'clone-modules'
  - Various internal refactoring
* Sun Jul 22 2018 coolo@suse.com
- updated to 0.84
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.84
  - Released at 2018-06-24T08:26:14+0900
  - Thanks to our contributors: Joelle Maslak
  - Unbreak 'available' command after some updates from cpan.org web site.
  - Unbreak the installation -- which missed "perlbrew" command due to a mistake when using mbtiny.
* Thu May 31 2018 coolo@suse.com
- updated to 0.83
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
* Wed Feb 21 2018 coolo@suse.com
- updated to 0.82
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  - Thanks to our contributors: Alceu Rodrigues de Freitas Junior, Paul Cochrane
  - Fix regression of 'perlbrew install blead'
  0.81: # 2017-12-09T15:12:04+0900
  - Thanks to our contributors: Luca Ferrari, Zac Bentley, perlancar, Nicolas R, gregor herrmann, Paul Cochrane
  - New command: clone-modules
  - Recognize tarball in .tar.xz extension
  - The output of "availables" is now sorted by versions
  - Unbreak the integration with cperl releases
  - Make `perlbrew install` runs correctly on AIX
  - support the current perl blead (5.28)
  0.80: # 2017-06-30T07:40:45+0200
  - Fix version in META.yml in CPAN distribution. See: https://rt.cpan.org/Public/Bug/Display.html?id=122279
  0.79: # 2017-06-25T23:40:45+0200
  - deal with perl-5.26 change about @INC in Makefile.PL
  - "available" command now also shows the URLs
* Mon Nov 21 2016 coolo@suse.com
- updated to 0.78
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.78: # 2016-11-20T22:59:55+0100
  - Thanks to our contributors: Manuel Streuhofer, Sergey Aleynikov
  - More fixes to accomodate changes on perl5.git.perl.org
* Sun Nov 13 2016 coolo@suse.com
- updated to 0.77
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.77: # 2016-11-12T06:42:45+0100
  - Thanks to our contributors: Dennis Kaarsemaker, Roel Harbers
  - The "uninstall" command now requires confirmation.
  - Fix bug with csh when PATH entries contain spaces
  - Accommodate git commit abbrivation changes on perl5.git.perl.org. See GH #524 https://github.com/gugod/App-perlbrew/pull/524
* Thu Jun 23 2016 coolo@suse.com
- updated to 0.76
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.76: # 2016-06-21T23:02:44+0200
  - Start supporting cperl installation.
  - cperl releases are sourced from: https://github.com/perl11/cperl/releases
  - Deal with a regex warning when testing perlbrew with perl-5.25. See RT: https://rt.cpan.org/Ticket/Display.html?id=114871
* Mon Apr  4 2016 coolo@suse.com
- updated to 0.75
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.75: # 2016-03-16T23:41:41+0100
  - Thanks to our contributors: Dave Cross,  Dean Hamstead,  Mark J. Reed,  Mohammed El-Afifi,
  - Add '--no-patchperl' install option for skip running patchperl.
  - Add '--destdir' install option.
  - "uninstall" command now also delete associated libs.
  - "mirror" command is removed.
  - "config" command is removed.
* Sat Nov 28 2015 coolo@suse.com
- updated to 0.74
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.74: # 2015-11-24T20:55:02+0100
  - A big thanks for our contributers: Aristotle Pagaltzis, Dave Jacoby, Dylan Cali, John Krull, Kevin Johnson, Nathan Day, Paul Cochrane, Tudor Constantin, Yanick Champoux, tm604
  - support PERLBREW_LIB_PREFIX. https://github.com/gugod/App-perlbrew/commit/c29813cd4633683bd049964178a9ac96647986bc
  - prefer https and remove insecure download cli flags. https://github.com/gugod/App-perlbrew/commit/f49a908c1702942006de4654107edf77a48ead52
  - perlbrew now dies when switching to/use a lib that does not exist. https://github.com/gugod/App-perlbrew/issues/432
  - RHEL vendorlib fix https://github.com/gugod/App-perlbrew/issues/409
  - improvements with fish integration.
  - unbreak when running with perl 5.14 or earlier: "list" command now correctly display lib names.
  - retaining flags in upgrade-perl. https://github.com/gugod/App-perlbrew/commit/b8d466670bbfc8e214a9d3ff2e889a4860060d84
  - variour document clean up and improvements.
* Fri Apr 17 2015 coolo@suse.com
- updated to 0.73
  see /usr/share/doc/packages/perl-App-perlbrew/Changes
  0.73: # 2015-02-01T09:59:45+0100
  - fixes and improvements from Manuel Streuhofer, Aristotle Pagaltzis, Sebastian Willert, David Hand, Eric Enns,
    Peter Roberts, Thomas Sibley, Ivan Baidakou, thanks!
  - fix 'perlbrew user' for fish users https://github.com/gugod/App-perlbrew/pull/429
  - fix sub-shell for bash users https://github.com/gugod/App-perlbrew/pull/435
  - clarify the 'perlbrew use' output: https://github.com/gugod/App-perlbrew/issues/439
  0.72: # 2014-10-27T21:38:19+0100
  - Fix 0.71 breakage on MacOSX when the shell is bash or zsh
  - Fix spelling mistake. by @gregoa++
* Mon Sep 15 2014 coolo@suse.com
- updated to 0.71
  - Fix a few bugs of having unwanted values in PERL5LIB when switching between libs
  0.70: # 2014-09-02T20:41:15+0900
  - download the fatpacked perlbrew from an http:// url.
  - protect fatpacked perlbrew from PERL5LIB, thanks to dagolden++
  - avoid several warnings, thanks to DabeDotCom++
  - making perlbrew a bit friendlier to init.d script, thanks to maxhq++ . see also https://github.com/gugod/App-perlbrew/pull/404
  - make it possible to override PERLBREWURL before invoking installers
  0.69: # 2014-06-10T23:32:05+0200
  - fix 'perlbrew env' breakage by just avoiding bad local::lib versions.
  0.68: # 2014-06-07T15:08:00+0200
  - disable SSL cert checks. GH #385.
  - "perlbrew download stable" works as on expects. GH #383
  - Many fish shell fixes. GH #376 #378 #379
  - make 5.21 installable. GH #396
  - various documentation fixes.
* Mon Mar 17 2014 coolo@suse.com
- buildrequire wget to please test suite
* Mon Nov 25 2013 coolo@suse.com
- updated to 0.67
  - Support fish shell. Thanks to @yenzie++
  - `info` command now takes an optional module name and show information for it. Thanks to @trcjr++
  - doc/bug fixes from @mmcclimon++, @mperry2++, and markstos++
* Tue Aug  6 2013 coolo@suse.com
- updated to 0.66
  - exec command: error hadndling improvements. Thanks to @vsespb.
  - install command: add "--clang" option. Thanks to @salva
  - various bug fixes. thanks to @ironcamel and @gottreu
* Tue Jun  4 2013 coolo@suse.com
- updated to 0.64
  - The build directory is removed before a new build.
  - New command: `install-multiple`
  - `clean` command now also removes tarballs
  - `install` command has many extra convienent flags.
  - Use "http://www.cpan.org" as the default CPAN mirror instead of "http://search.cpan.org/CPAN"
  - Remove the --insecure/--no-check-certificate command bflags when invoking curl/wget.
  - Remove `install-ack` command.
  - Due to the new architecture of ack2, it does not make sense
    to install the standalone executable anymore. Thus it's better not
    to do the installation with perlbrew.
  - Fix the `use` and `switch` command when switching between binary incompatible perl installations. See GH #297
  - Fix `list-modules` under lib env. It lists all modules in the lib, and in the base.
  - Use the original grep command to prevent aliases from breaking the content of init. GH #307
  - `perlbrew alias help` is now the same as `perlbrew help alias`
  - `perlbrew exec --with ...` now preserve the order of specified names.
  - Fix bashrc on various OS/shell. See GH #302
  - Exit status handling in bash function. See ed29288ab50a15d7df86d69cfcbddf108674eb07 for more details.
  - Fix compatibility with recent local::lib version.
  - Delay the loading of server modules.
  - Fix warnings when runing `perlbrew off`
* Fri Oct 26 2012 coolo@suse.com
- explict buildrequire groff for the test suite
* Fri May 25 2012 coolo@suse.com
- updated to 0.42
  - Improvement: die when running perlbrew (use|switch) with unknown installation name.
  - clean 'build.log' on install. ref: RT #69168.
* Tue Feb 21 2012 coolo@suse.com
- updated to 0.41
  - Fix installation issue when the specified version is not listed in CPAN::Perl::Releases
  - Fix sub-shell invocation for 'switch' and 'use' command. This is particularly for csh users, but it should also work for bash users.
  - Make the stanalone perlbrew program smaller by using Perl::Strip
  - use CPAN::Perl::Releases to decide the location of perl tarball -- less HTTP hits
  - Prefer $PERLBREW_ROOT/bin/patchperl if it is there.
* Mon Jan  2 2012 pascal.bleser@opensuse.org
- update to 0.39:
  * Fix GH #179. lib naming are more consistent
  * Fix GH #171. bash users are suggestted to upgrad to this version
  * Fix GH #152
- changes from 0.38:
  * fix deps
- changes from 0.37:
  * fix ENV mess after switching to diffirent libs multiple times
  * add --sitecustomize option
* Sat Dec 17 2011 pascal.bleser@opensuse.org
- update to 0.35:
  * fixes for cpantester failures
  * requires local::lib version 1.008
- update to 0.34:
  * fix: remove duplicated items from the output of `perlbrew list`
  * new Command: self-install:
  - this is actually renamed from an undocumented command `install-perlbrew`
  - plus it gets documented
  * provide aditional bash completion control helper commands
  * alter MANPATHs, see GH#173
  * allow the representation like '@lib' te mean "a lib name under current
    perl." GH#153
* Fri Nov 18 2011 pascal.bleser@opensuse.org
- update to 0.33:
  * remove Text::Levenshtein from the standalone executable
  * rearrange documentation so all perlbrew command usage document can be found
    in `perldoc perlbrew`
- changes from 0.32:
  * hotfix release: local::lib was not bundled in the previous release
* Thu Nov  3 2011 pascal.bleser@opensuse.org
- update to 0.31:
  * NOTICE: remove $PERLBREW_ROOT/Conf.pm if it's there, and re-run `perlbrew
    mirror`
  * perlbrew help system is changing. `perlbrew help <command>` now displays
    brief documentation for the command
  * add a global `--root` argument for all commands that can be used as a quick
    alternative to set PERLBREW_ROOT env var
  * avoid display paths to external/system perl in the output of `perlbrew
    list`
  * replace Text::Levenshtein with a minimal implementation -- the standalone
    executable get to be smaller
- changes from 0.30:
  * new command: lib: local::lib integration is done with this command
  * new command: install-patchperl
  * skip runs of 'exec' on aliases
  * respect -f flag when installing to replace an already installed perl
  * redefine the default value of -q flag to be false, and define it's meaning
    to be "complete silent"
* Fri Sep 30 2011 pascal.bleser@opensuse.org
- update to 0.29:
  * the installer now honors $TMPDIR (RT #70850)
  * fixed GH #108. `perlbrew use` has a fallback for users that does not use
    bash/csh -compitable shell
  * deprecate the command 'perlbrew use system' simply use 'perlbrew off' or
    'perlbrew switch-off' instead
  * deprecate the special case of `perlbrew use /path/to/bin/perl` and
    `perlbrew switch /path/to/bin/perl`
  * perlbrew no longer cast magic to external perls; but there will be an
    alternative
- changes from 0.28:
  * fixes for cpantester
  * fix 'switch' and 'use' for bash users
  * the standalone `perlbrew` file is now packed with fatpacker, by running
    `dev-bin/build.sh`. `perl Makefile.PL` does no trigger a re-build anymore
  * update the installer to grab patchperl 0.46
- changes from 0.26:
  * fix GH #119
  * fix several bugs in `exec` command
  * implement GH #103 - install -v shows build.log
  * add -Dusedevel when installing blead perl
- changes from 0.25:
  * suggest when user types wrong commands
  * improvements about self-upgrade
  * exit with non-zero status code when there's some sort of error
  * added verification of existing alias before attempting unalias
  * fix `install-cpanm` for due to a recenet github cert update
* Wed Jun  8 2011 pascal.bleser@opensuse.org
- update to 0.24:
  * done GH#92 -- Show error messages on network errors
  * fix GH#82 -- deduplicate items in PATH for the `list` command
* Wed Jun  1 2011 pascal.bleser@opensuse.org
- update to 0.23:
  * dependency fixes
  * fix auto-detection of curl
  * small improvement of 'exec' command. `perlbrew exec perl -v` now works.
* Thu May 26 2011 pascal.bleser@opensuse.org
- update to 0.22:
  * fix ccache support on Linux with bash.. GH#87
  * new commands: uninstall, alias, self-upgrade
* Tue May 17 2011 pascal.bleser@opensuse.org
- update to 0.21:
  * let version numbers alone mean installation names: for example, 5.12.3 means perl-5.12.3
  * fixed `perlbrew install <URL>` that might installs to a wrong path
  * fix RT#68241
  * improve `perlbrew list` command output
  * improve `perlbrew install` command: now it takes a local .tar.gz filename
* Tue May 10 2011 pascal.bleser@opensuse.org
- update to 0.20:
  * for more detail release note, see
    https://github.com/gugod/App-perlbrew/wiki/Release-0.20
  * FIX: stop when user specified an invalid perl version that cannot be found
    on cpan
  * specialized version installation: perlbrew install perl-blead / <URL>
  * FIX: `perlbrew install /path/to/git/src/dir`
* Wed Apr 27 2011 coolo@opensuse.org
- updated to 0.19
  - Auto run 'perlbrew init' after an install (or upgrade)
  - Symlink dev versions of executables. For example,'perl5.13.11' to 'perl',
    'prove5.13.11' to 'prove'.
  - Automatically apply patches necessary to make older perls build again on
    modern platforms with the help of Devel::PatchPerl.
  - A command "perlbrew available" to list recently available perls to build by
    trcjr
* Sun Apr  3 2011 coolo@novell.com
- updated to 0.18
  * Spotted and fixed by chad.a.davis++, an issue when bash set "noclobber"
    option, which breaks the creation of ~/.perlbrew/init. See
    https://rt.cpan.org/Ticket/Display.html?id=66518
  * A simple `perlbrew clean` command to clean build dir.
  * delegate `-j` arg value to `make test_harness`. by dagolden++
  * $HOME is replaced with "~" in many messages.
    https://rt.cpan.org/Ticket/Display.html?id=57668
* Wed Mar  9 2011 pascal.bleser@opensuse.org
- update to 0.17:
  * fix "perlbrew use" to work even if we are switched to a specific version
  * fix "perlbrew env" to use current version, sets PERLBREW_PERL and proper
    PATH
  * feature: "perlbrew use" shows current version in use
  * feature: "perlbrew switch /path/to/special/perl name-of-special-perl" names
    for adhoc perl's
  * 'perlbrew exec' now excludes those non-brewed perl by frankcuny++ according
    to the discussion here: https://github.com/gugod/App-perlbrew/pull/43
* Sat Feb 19 2011 pascal.bleser@opensuse.org
- update to 0.16:
  * fix "perlbrew -f switch"
* Fri Jan 14 2011 coolo@novell.com
- initial package 0.15
  * created by cpanspec 1.78.03
